@@ -1,12 +1,24 @@
-#!perl
-# $Id: /mirror/perl/Text-MeCab/trunk/tools/probe_mecab.pl 38046 2008-01-06T12:44:20.889262Z daisuke  $
-#
-# Copyright (c) 2006-2008 Daisuke Maki <daisuke@endeworks.jp>
-# All rights reserved.
+#!/usr/bin/env perl
 
 use strict;
 use File::Spec;
-use ExtUtils::MakeMaker;
+use Getopt::Long;
+use ExtUtils::MakeMaker ();
+
+my $default_encoding = 'euc-jp';
+my $default_config;
+if (! GetOptions(
+    "encoding=s" => \$default_encoding,
+    "mecab-config=s" => \$default_config,
+)) {
+    exit 1;
+}
+
+# XXX Silly hack
+local *STDIN = *STDIN;
+if ($ENV{TRAVIS_TEST}) {
+    close STDIN;
+}
 
 my($version, $cflags, $libs, $include, $mecab_config);
 
@@ -15,7 +27,7 @@ $mecab_config = '';
 
 # Save the poor puppies that run on Windows
 if ($^O eq 'MSWin32') {
-    $version = prompt(
+    $version = ExtUtils::MakeMaker::prompt(
         join(
             "\n",
             "",
@@ -34,28 +46,33 @@ if ($^O eq 'MSWin32') {
         )
     );
     chomp $version;
-    die "no version specified! cowardly refusing to proceed." unless $version;
 
-    $cflags  = prompt("Additional compiler flags (e.g. -DWIN32 -Ic:\\path\\to\\mecab\\sdk)? []");
+    if (! $version) {
+        print STDERR "no version specified! cowardly refusing to proceed.";
+        exit;
+    }
 
-    $libs    = prompt("Additional linker flags (e.g. -lc:\\path\\to\\mecab\\sdk\\libmecab.lib)? [] ");
-    $include = prompt("Directory containing mecab.h (e.g. c:\\path\\to\\include)? [] ");
+    $cflags  = ExtUtils::MakeMaker::prompt("Additional compiler flags (e.g. -DWIN32 -Ic:\\path\\to\\mecab\\sdk)? []");
+
+    $libs    = ExtUtils::MakeMaker::prompt("Additional linker flags (e.g. -lc:\\path\\to\\mecab\\sdk\\libmecab.lib)? [] ");
+    $include = ExtUtils::MakeMaker::prompt("Directory containing mecab.h (e.g. c:\\path\\to\\include)? [] ");
 } else {
     # try probing in places where we expect it to be
-    my $default_config;
-    foreach my $path qw(/usr/bin /usr/local/bin) {
-        my $tmp = File::Spec->catfile($path, 'mecab-config');
-        if (-f $tmp && -x _) {
-            $default_config = $tmp;
-            last;
+    if (! defined $default_config || ! -x $default_config) {
+        foreach my $path (qw(/usr/bin /usr/local/bin /opt/local/bin)) {
+            my $tmp = File::Spec->catfile($path, 'mecab-config');
+            if (-f $tmp && -x _) {
+                $default_config = $tmp;
+                last;
+            }
         }
     }
 
-    $mecab_config = prompt( "Path to mecab config?", $default_config );
+    $mecab_config = ExtUtils::MakeMaker::prompt( "Path to mecab config?", $default_config );
 
     if (!-f $mecab_config || ! -x _) {
         print STDERR "Can't proceed without mecab-config. Aborting...\n";
-        exit 1;
+        exit;
     }
     
     $version = `$mecab_config --version`;
@@ -95,8 +112,7 @@ if ($libs) {
     print "No linker flags specified\n";
 }
 
-my $default_encoding = 'utf-8';
-my $encoding = prompt(
+my $encoding = ExtUtils::MakeMaker::prompt(
     join(
         "\n",
         "",
